@@ -110,7 +110,9 @@ QStringList Controller::getProxyFromDB() const {
     db.setDatabaseName("/home/user/.config/cutetube/Databases/63db502ea46fc7fe74e01e615d2c00d6.sqlite");
     db.open();
 
-    QSqlQuery query("select value from settings where setting = 'proxy'");
+    QSqlQuery query;
+    query.exec("insert or ignore into settings values ('proxy', ':')");
+    query.exec("select value from settings where setting = 'proxy'");
     QSqlRecord record = query.record();
     QStringList proxy;
     QString result;
@@ -119,11 +121,12 @@ QStringList Controller::getProxyFromDB() const {
             result = query.value(0).toString();
             proxy = result.split(":");
         }
-        //        qDebug() << proxy;
+//        qDebug() << proxy;
     }
     else {
         proxy << "" << "";
     }
+//    qDebug() << proxy;
     db.close();
     return proxy;
 }
