@@ -13,8 +13,8 @@ DownloadManager::DownloadManager(QObject *parent) :
     dlMap["720p"] = 22;
     dlMap["480p"] = 35;
     dlMap["360p"] = 34;
-    dlMap["High quality"] = 18;
-    dlMap["Mobile"] = 5;
+    dlMap["hq"] = 18;
+    dlMap["mobile"] = 5;
 
     connect(this, SIGNAL(gotVideoUrl(QByteArray)), this, SLOT(performDownload(QByteArray)));
 }
@@ -34,7 +34,7 @@ void DownloadManager::getVideoUrl(const QString &playerUrl) {
 
 void DownloadManager::parseVideoPage() {
     if (downloadReply->error()) {
-        emit statusChanged(tr("Failed"));
+        emit statusChanged("failed");
         return;
     }
     QMap<int, QByteArray> formats;
@@ -63,7 +63,7 @@ void DownloadManager::parseVideoPage() {
         index++;
     }
     if (videoUrl == "") {
-        emit statusChanged(tr("Failed"));
+        emit statusChanged("failed");
     }
     else {
         emit gotVideoUrl(videoUrl);
@@ -93,7 +93,8 @@ void DownloadManager::startDownload(const QString &filePath, const QString &url)
         }
     }
     else if (!output.open(QIODevice::WriteOnly)) {
-        qDebug() << "No write permissions";
+//        qDebug() << "No write permissions";
+        emit statusChanged("failed");
         downloading = false;
         return;                 // skip this download
     }
@@ -118,7 +119,7 @@ void DownloadManager::performDownload(const QByteArray &videoUrl) {
     }
 
     downloadReply = nam->get(request);
-    emit statusChanged(tr("Downloading"));
+    emit statusChanged("downloading");
     downloadTime.start();
     connect(downloadReply, SIGNAL(downloadProgress(qint64, qint64)), this, SLOT(updateProgress(qint64,qint64)));
     connect(downloadReply, SIGNAL(finished()), this, SLOT(downloadFinished()));
@@ -153,10 +154,10 @@ void DownloadManager::downloadFinished() {
         QString status;
         if (downloadReply->error()) {
             if (downloadReply->error() == QNetworkReply::OperationCanceledError) {
-                status = tr("Paused");
+                status = "paused";
             }
             else {
-                status = tr("Failed");
+                status = "failed";
             }
             emit statusChanged(status);
         }
