@@ -32,9 +32,13 @@
         <translation type="obsolete">cuteTube-QML - 0.6.1 in deutsch</translation>
     </message>
     <message>
-        <location filename="../AboutDialog.qml" line="44"/>
         <source>cuteTube-QML - 0.6.3</source>
-        <translation>cuteTube-QML - 0.6.3 in deutsch</translation>
+        <translation type="obsolete">cuteTube-QML - 0.6.3 in deutsch</translation>
+    </message>
+    <message>
+        <location filename="../AboutDialog.qml" line="44"/>
+        <source>cuteTube-QML - 0.6.5</source>
+        <translation>cuteTube-QML - 0.6.5 in deutsch</translation>
     </message>
     <message>
         <location filename="../AboutDialog.qml" line="56"/>
@@ -74,12 +78,12 @@
         <translation>Benutzername</translation>
     </message>
     <message>
-        <location filename="../AccountDetailsDialog.qml" line="107"/>
+        <location filename="../AccountDetailsDialog.qml" line="95"/>
         <source>Password</source>
         <translation>Passwort</translation>
     </message>
     <message>
-        <location filename="../AccountDetailsDialog.qml" line="132"/>
+        <location filename="../AccountDetailsDialog.qml" line="108"/>
         <source>Default?</source>
         <translation>Standard?</translation>
     </message>
@@ -122,12 +126,12 @@
         <translation>Titel</translation>
     </message>
     <message>
-        <location filename="../AddCommentDialog.qml" line="87"/>
+        <location filename="../AddCommentDialog.qml" line="74"/>
         <source>Description</source>
         <translation>Beschreibung</translation>
     </message>
     <message>
-        <location filename="../AddCommentDialog.qml" line="124"/>
+        <location filename="../AddCommentDialog.qml" line="111"/>
         <source>Message</source>
         <translation>Mitteilung</translation>
     </message>
@@ -223,52 +227,46 @@
 <context>
     <name>Controller</name>
     <message>
-        <location filename="../../../controller.cpp" line="46"/>
         <source>English</source>
-        <translation>Englisch</translation>
+        <translation type="obsolete">Englisch</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="47"/>
         <source>German</source>
-        <translation>Deutsch</translation>
+        <translation type="obsolete">Deutsch</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="48"/>
         <source>Italian</source>
-        <translation>Italienisch</translation>
+        <translation type="obsolete">Italienisch</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="49"/>
         <source>Finnish</source>
-        <translation>Finnisch</translation>
+        <translation type="obsolete">Finnisch</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="50"/>
         <source>Dutch</source>
-        <translation>Niederländisch</translation>
+        <translation type="obsolete">Niederländisch</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="51"/>
         <source>Polish</source>
-        <translation>Polnisch</translation>
+        <translation type="obsolete">Polnisch</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="177"/>
+        <location filename="../../../controller.cpp" line="181"/>
         <source>Video deleted from device</source>
         <translation>Video vom Gerät gelöscht</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="180"/>
+        <location filename="../../../controller.cpp" line="184"/>
         <source>Unable to delete video</source>
         <translation>Löschen des Videos nicht möglich</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="184"/>
+        <location filename="../../../controller.cpp" line="188"/>
         <source>Video not found</source>
         <translation>Video nicht gefunden</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="239"/>
+        <location filename="../../../controller.cpp" line="243"/>
         <source>Copied to clipboard</source>
         <translation>In Zwischenablage kopiert</translation>
     </message>
@@ -276,44 +274,35 @@
 <context>
     <name>DownloadListDelegate</name>
     <message>
-        <location filename="../DownloadListDelegate.qml" line="49"/>
         <source>Paused</source>
-        <translation>Pausiert</translation>
+        <translation type="obsolete">Pausiert</translation>
     </message>
     <message>
-        <location filename="../DownloadListDelegate.qml" line="49"/>
         <source>Queued</source>
-        <translation>in Warteschlange</translation>
+        <translation type="obsolete">in Warteschlange</translation>
     </message>
     <message>
-        <location filename="../DownloadListDelegate.qml" line="49"/>
         <source>Failed</source>
-        <translation>Fehlgeschlagen</translation>
+        <translation type="obsolete">Fehlgeschlagen</translation>
     </message>
     <message>
-        <location filename="../DownloadListDelegate.qml" line="66"/>
         <source>Downloading</source>
-        <translation>am Herrunterladen</translation>
+        <translation type="obsolete">am Herrunterladen</translation>
     </message>
 </context>
 <context>
     <name>DownloadManager</name>
     <message>
-        <location filename="../../../downloadmanager.cpp" line="37"/>
-        <location filename="../../../downloadmanager.cpp" line="66"/>
-        <location filename="../../../downloadmanager.cpp" line="159"/>
         <source>Failed</source>
-        <translation>Fehlgeschlagen</translation>
+        <translation type="obsolete">Fehlgeschlagen</translation>
     </message>
     <message>
-        <location filename="../../../downloadmanager.cpp" line="121"/>
         <source>Downloading</source>
-        <translation>am Herrunterladen</translation>
+        <translation type="obsolete">am Herrunterladen</translation>
     </message>
     <message>
-        <location filename="../../../downloadmanager.cpp" line="156"/>
         <source>Paused</source>
-        <translation>Pausiert</translation>
+        <translation type="obsolete">Pausiert</translation>
     </message>
 </context>
 <context>
@@ -444,12 +433,12 @@
         <translation>Titel</translation>
     </message>
     <message>
-        <location filename="../NewPlaylistDialog.qml" line="71"/>
+        <location filename="../NewPlaylistDialog.qml" line="59"/>
         <source>Description (optional)</source>
         <translation>Beschreibung (optional)</translation>
     </message>
     <message>
-        <location filename="../NewPlaylistDialog.qml" line="95"/>
+        <location filename="../NewPlaylistDialog.qml" line="71"/>
         <source>Private?</source>
         <translation>Privat?</translation>
     </message>
@@ -572,33 +561,48 @@
         <translation>Keine Wiedergabelisten gefunden</translation>
     </message>
 </context>
+<context>
+    <name>ProxyDialog</name>
+    <message>
+        <location filename="../ProxyDialog.qml" line="30"/>
+        <source>Network Proxy</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ProxyDialog.qml" line="44"/>
+        <source>Host (e.g. 192.168.100.1)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ProxyDialog.qml" line="51"/>
+        <source>Port (e.g. 8080)</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>SearchBar</name>
     <message>
-        <location filename="../SearchBar.qml" line="116"/>
-        <location filename="../SearchBar.qml" line="126"/>
+        <location filename="../SearchBar.qml" line="15"/>
         <source>Date</source>
         <translation>Datum</translation>
     </message>
     <message>
-        <location filename="../SearchBar.qml" line="117"/>
-        <location filename="../SearchBar.qml" line="119"/>
+        <location filename="../SearchBar.qml" line="15"/>
         <source>Relevance</source>
         <translation>Relevanz</translation>
     </message>
     <message>
-        <location filename="../SearchBar.qml" line="120"/>
-        <location filename="../SearchBar.qml" line="122"/>
+        <location filename="../SearchBar.qml" line="15"/>
         <source>Rating</source>
         <translation>Bewertung</translation>
     </message>
     <message>
-        <location filename="../SearchBar.qml" line="123"/>
+        <location filename="../SearchBar.qml" line="15"/>
         <source>Views</source>
         <translation>Aufrufe</translation>
     </message>
     <message>
-        <location filename="../SearchBar.qml" line="176"/>
+        <location filename="../SearchBar.qml" line="183"/>
         <source>Order by:</source>
         <translation>Sortieren nach:</translation>
     </message>
@@ -606,223 +610,317 @@
 <context>
     <name>SettingsDialog</name>
     <message>
-        <location filename="../SettingsDialog.qml" line="144"/>
+        <location filename="../SettingsDialog.qml" line="189"/>
         <source>Your saved searches have been cleared</source>
         <translation>Die gespeicherten Suchen wurden gelöscht</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="147"/>
+        <location filename="../SettingsDialog.qml" line="192"/>
         <source>Database error. Unable to clear searches</source>
         <translation>Datenbankfehler. Konnte Konto nicht speichern</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="196"/>
+        <location filename="../SettingsDialog.qml" line="239"/>
         <source>Settings</source>
         <translation>Optionen</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="229"/>
+        <location filename="../SettingsDialog.qml" line="280"/>
         <source>Playback quality</source>
         <translation>Wiedergabequalität</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="237"/>
+        <location filename="../SettingsDialog.qml" line="288"/>
         <source>Download quality</source>
         <translation>Downloadqualität</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="245"/>
+        <location filename="../SettingsDialog.qml" line="296"/>
         <source>Start downloads</source>
         <translation>Downloads starten</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="253"/>
+        <location filename="../SettingsDialog.qml" line="304"/>
         <source>Download location</source>
         <translation>Downloadverzeichnis</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="269"/>
+        <location filename="../SettingsDialog.qml" line="320"/>
         <source>Screen orientation</source>
         <translation>Bildschirmausrichtung</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="277"/>
+        <location filename="../SettingsDialog.qml" line="328"/>
         <source>Media player</source>
         <translation>Media Player</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="135"/>
-        <location filename="../SettingsDialog.qml" line="294"/>
-        <location filename="../SettingsDialog.qml" line="466"/>
+        <location filename="../SettingsDialog.qml" line="165"/>
+        <location filename="../SettingsDialog.qml" line="345"/>
+        <location filename="../SettingsDialog.qml" line="537"/>
         <source>Language</source>
         <translation>Sprache</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="111"/>
-        <location filename="../SettingsDialog.qml" line="320"/>
+        <location filename="../SettingsDialog.qml" line="37"/>
+        <location filename="../SettingsDialog.qml" line="38"/>
+        <source>High quality</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="43"/>
+        <source>Russian</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="44"/>
+        <source>Most recent</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="44"/>
+        <source>Most viewed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="45"/>
+        <source>Archive</source>
+        <translation type="unfinished">Archiv</translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="45"/>
+        <source>Latest subscription videos</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="46"/>
+        <source>My uploads</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="46"/>
+        <source>My favourites</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="117"/>
+        <location filename="../SettingsDialog.qml" line="168"/>
+        <source>Network Proxy</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="141"/>
+        <location filename="../SettingsDialog.qml" line="391"/>
         <source>Playback Quality</source>
         <translation>Wiedergabequalität</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="114"/>
-        <location filename="../SettingsDialog.qml" line="338"/>
+        <location filename="../SettingsDialog.qml" line="144"/>
+        <location filename="../SettingsDialog.qml" line="409"/>
         <source>Download Quality</source>
         <translation>Downloadqualität</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="117"/>
-        <location filename="../SettingsDialog.qml" line="356"/>
+        <location filename="../SettingsDialog.qml" line="147"/>
+        <location filename="../SettingsDialog.qml" line="427"/>
         <source>Start Downloads</source>
         <translation>Downloads starten</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="126"/>
-        <location filename="../SettingsDialog.qml" line="412"/>
+        <location filename="../SettingsDialog.qml" line="156"/>
+        <location filename="../SettingsDialog.qml" line="483"/>
         <source>Screen Orientation</source>
         <translation>Bildschirmausrichtung</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="129"/>
-        <location filename="../SettingsDialog.qml" line="430"/>
+        <location filename="../SettingsDialog.qml" line="159"/>
+        <location filename="../SettingsDialog.qml" line="501"/>
         <source>Media Player</source>
         <translation>Media Player</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="17"/>
-        <location filename="../SettingsDialog.qml" line="18"/>
+        <location filename="../SettingsDialog.qml" line="37"/>
+        <location filename="../SettingsDialog.qml" line="38"/>
         <source>Mobile</source>
         <translation>Mobil</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="17"/>
-        <location filename="../SettingsDialog.qml" line="18"/>
         <source>High Quality</source>
-        <translation>Hohe Qualität</translation>
+        <translation type="obsolete">Hohe Qualität</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="19"/>
         <location filename="../SettingsDialog.qml" line="39"/>
-        <location filename="../SettingsDialog.qml" line="72"/>
         <source>Automatically</source>
         <translation>Automatisch</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="19"/>
-        <location filename="../SettingsDialog.qml" line="42"/>
+        <location filename="../SettingsDialog.qml" line="39"/>
         <source>Manually</source>
         <translation>Manuell</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="20"/>
-        <location filename="../SettingsDialog.qml" line="46"/>
-        <location filename="../SettingsDialog.qml" line="78"/>
+        <location filename="../SettingsDialog.qml" line="40"/>
         <source>On</source>
         <translation>Auf</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="20"/>
-        <location filename="../SettingsDialog.qml" line="49"/>
+        <location filename="../SettingsDialog.qml" line="40"/>
         <source>Off</source>
         <translation>Off</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="21"/>
+        <location filename="../SettingsDialog.qml" line="41"/>
         <source>Automatic</source>
         <translation>Automatisch</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="21"/>
+        <location filename="../SettingsDialog.qml" line="41"/>
         <source>Landscape</source>
         <translation>Querformat</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="21"/>
+        <location filename="../SettingsDialog.qml" line="41"/>
         <source>Portrait</source>
         <translation>Hochformat</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="23"/>
+        <location filename="../SettingsDialog.qml" line="42"/>
         <source>Light</source>
         <translation>Hell</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="23"/>
+        <location filename="../SettingsDialog.qml" line="42"/>
         <source>Dark</source>
         <translation>Dunkel</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="24"/>
+        <location filename="../SettingsDialog.qml" line="43"/>
         <source>English</source>
         <translation>Englisch</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="24"/>
+        <location filename="../SettingsDialog.qml" line="43"/>
         <source>German</source>
         <translation>Deutsch</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="24"/>
+        <location filename="../SettingsDialog.qml" line="43"/>
         <source>Finnish</source>
         <translation>Finnisch</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="24"/>
+        <location filename="../SettingsDialog.qml" line="43"/>
         <source>Italian</source>
         <translation>Italienisch</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="24"/>
+        <location filename="../SettingsDialog.qml" line="43"/>
         <source>Dutch</source>
         <translation>Niederländisch</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="24"/>
+        <location filename="../SettingsDialog.qml" line="43"/>
         <source>Polish</source>
         <translation>Polnisch</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="38"/>
-        <location filename="../SettingsDialog.qml" line="73"/>
         <source>Queued</source>
-        <translation>in Warteschlange</translation>
+        <translation type="obsolete">in Warteschlange</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="76"/>
         <source>Paused</source>
-        <translation>Pausiert</translation>
+        <translation type="obsolete">Pausiert</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="85"/>
+        <location filename="../SettingsDialog.qml" line="102"/>
         <source>Your settings have been saved</source>
         <translation>Ihre Einstellungen wurden gespeichert</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="90"/>
-        <location filename="../SettingsDialog.qml" line="120"/>
+        <location filename="../SettingsDialog.qml" line="107"/>
+        <location filename="../SettingsDialog.qml" line="150"/>
         <source>Download Path</source>
         <translation>Downloadverzeichnis</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="92"/>
+        <location filename="../SettingsDialog.qml" line="109"/>
         <source>Download Location</source>
         <translation>Downloadverzeichnis</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="123"/>
-        <location filename="../SettingsDialog.qml" line="261"/>
-        <location filename="../SettingsDialog.qml" line="394"/>
+        <location filename="../SettingsDialog.qml" line="153"/>
+        <location filename="../SettingsDialog.qml" line="465"/>
         <source>Safe Search</source>
         <translation>Sicher Suchlauf</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="132"/>
-        <location filename="../SettingsDialog.qml" line="285"/>
-        <location filename="../SettingsDialog.qml" line="448"/>
+        <location filename="../SettingsDialog.qml" line="162"/>
+        <location filename="../SettingsDialog.qml" line="336"/>
+        <location filename="../SettingsDialog.qml" line="519"/>
         <source>Theme</source>
         <translation>Thema</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="480"/>
+        <location filename="../SettingsDialog.qml" line="171"/>
+        <location filename="../SettingsDialog.qml" line="619"/>
+        <source>Widget Feed One</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="174"/>
+        <location filename="../SettingsDialog.qml" line="639"/>
+        <source>Widget Feed Two</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="177"/>
+        <location filename="../SettingsDialog.qml" line="659"/>
+        <source>Widget Feed Three</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="180"/>
+        <location filename="../SettingsDialog.qml" line="679"/>
+        <source>Widget Feed Four</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="272"/>
+        <source>Network proxy</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="312"/>
+        <source>Safe search</source>
+        <translation>Sicher suchlauf</translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="364"/>
+        <source>None</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="568"/>
+        <source>Feed One</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="576"/>
+        <source>Feed Two</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="584"/>
+        <source>Feed Three</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="592"/>
+        <source>Feed Four</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="694"/>
         <source>Clear saved searches</source>
         <translation>Lösche Suche</translation>
     </message>
@@ -934,7 +1032,7 @@
     </message>
     <message>
         <location filename="../UploadDialog.qml" line="35"/>
-        <location filename="../UploadDialog.qml" line="251"/>
+        <location filename="../UploadDialog.qml" line="215"/>
         <source>Category</source>
         <translation>Kategorie</translation>
     </message>
@@ -954,7 +1052,7 @@
     </message>
     <message>
         <location filename="../UploadDialog.qml" line="147"/>
-        <location filename="../UploadDialog.qml" line="259"/>
+        <location filename="../UploadDialog.qml" line="223"/>
         <source>None chosen</source>
         <translation>Keins ausgewählt</translation>
     </message>
@@ -964,17 +1062,17 @@
         <translation>Titel</translation>
     </message>
     <message>
-        <location filename="../UploadDialog.qml" line="188"/>
+        <location filename="../UploadDialog.qml" line="176"/>
         <source>Description (optional)</source>
         <translation>Beschreibung (optional)</translation>
     </message>
     <message>
-        <location filename="../UploadDialog.qml" line="212"/>
+        <location filename="../UploadDialog.qml" line="188"/>
         <source>Tags (seperated by commas)</source>
         <translation>Tags (durch Kommata getrennt)</translation>
     </message>
     <message>
-        <location filename="../UploadDialog.qml" line="237"/>
+        <location filename="../UploadDialog.qml" line="201"/>
         <source>Private?</source>
         <translation>Privat?</translation>
     </message>
@@ -1272,9 +1370,8 @@
 <context>
     <name>VideoPlaybackView</name>
     <message>
-        <location filename="../VideoPlaybackView.qml" line="60"/>
         <source>Error: Unable to retrieve video</source>
-        <translation>Fehler: Kann Video nicht empfangen</translation>
+        <translation type="obsolete">Fehler: Kann Video nicht empfangen</translation>
     </message>
 </context>
 <context>
@@ -1372,49 +1469,50 @@
 <context>
     <name>YouTube</name>
     <message>
-        <location filename="../../../youtube.cpp" line="39"/>
+        <location filename="../../../youtube.cpp" line="40"/>
         <source>Error obtaining access token</source>
         <translation>Fehler beim Zugangscode</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="49"/>
+        <location filename="../../../youtube.cpp" line="50"/>
         <source>Authentication failed</source>
         <translation>Autorisierung schlug fehl</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="52"/>
+        <location filename="../../../youtube.cpp" line="53"/>
         <source>You are signed in to YouTube as &apos;</source>
         <translation>Bei YouTube angemeldet als &apos;</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="115"/>
-        <location filename="../../../youtube.cpp" line="221"/>
+        <location filename="../../../youtube.cpp" line="116"/>
+        <location filename="../../../youtube.cpp" line="222"/>
         <source>Error - Server repsonse is: </source>
         <translation>Fehler - Serverantwort ist:</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="165"/>
-        <location filename="../../../youtube.cpp" line="173"/>
+        <location filename="../../../youtube.cpp" line="166"/>
+        <location filename="../../../youtube.cpp" line="174"/>
         <source>Upload aborted</source>
         <translation>Upload abgebrochen</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="180"/>
+        <location filename="../../../youtube.cpp" line="181"/>
         <source>Upload interrupted. Attempting to resume...</source>
         <translation>Upload unterbrochen. Versuche wiederaufnahme...</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="184"/>
+        <location filename="../../../youtube.cpp" line="185"/>
         <source>Upload failed</source>
         <translation>Upload fehlgeschlagen</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="190"/>
+        <location filename="../../../youtube.cpp" line="191"/>
         <source>Upload is completed</source>
         <translation>Upload ist komplett</translation>
     </message>
     <message>
         <location filename="../../../youtube.cpp" line="382"/>
+        <location filename="../../../youtube.cpp" line="419"/>
         <source>Error: Unable to retrieve video</source>
         <translation>Fehler: Kann Video nicht empfangen</translation>
     </message>
@@ -1422,17 +1520,12 @@
 <context>
     <name>main</name>
     <message>
-        <location filename="../main.qml" line="18"/>
         <source>Dark</source>
-        <translation>Dunkel</translation>
+        <translation type="obsolete">Dunkel</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="21"/>
-        <location filename="../main.qml" line="22"/>
-        <location filename="../main.qml" line="23"/>
-        <location filename="../main.qml" line="24"/>
         <source>Light</source>
-        <translation>Hell</translation>
+        <translation type="obsolete">Hell</translation>
     </message>
     <message>
         <location filename="../main.qml" line="109"/>
@@ -1460,9 +1553,13 @@
         <translation>Neue Wiedergabeliste erstellt</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="200"/>
         <source>Converting</source>
-        <translation>Konvertiere</translation>
+        <translation type="obsolete">Konvertiere</translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="204"/>
+        <source>Audio</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../main.qml" line="209"/>
@@ -1475,24 +1572,57 @@
         <translation>&apos; gescheitert</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="223"/>
-        <location filename="../main.qml" line="230"/>
-        <location filename="../main.qml" line="270"/>
+        <location filename="../main.qml" line="224"/>
+        <source>High quality</source>
+        <translation>Hohe qualität</translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="224"/>
+        <source>Mobile</source>
+        <translation>Mobil</translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="224"/>
+        <source>360p</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="224"/>
+        <source>480p</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="224"/>
+        <source>720p</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="225"/>
         <source>Queued</source>
         <translation>in Warteschlange</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="238"/>
+        <location filename="../main.qml" line="225"/>
         <source>Paused</source>
         <translation>Pausiert</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="415"/>
+        <location filename="../main.qml" line="225"/>
+        <source>Downloading</source>
+        <translation>am Herrunterladen</translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="225"/>
+        <source>Failed</source>
+        <translation>Fehlgeschlagen</translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="422"/>
         <source>Most Recent</source>
         <translation>Aktuellste Videos</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="416"/>
+        <location filename="../main.qml" line="423"/>
         <source>Most Viewed</source>
         <translation>Meistgesehen</translation>
     </message>
@@ -1509,57 +1639,52 @@
         <translation>Mein Kanal</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="133"/>
+        <location filename="../scripts/mainscripts.js" line="134"/>
         <source>Archive</source>
         <translation>Archiv</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="172"/>
+        <location filename="../scripts/mainscripts.js" line="173"/>
         <source>My Playlists</source>
         <translation>Mein Wiedergabelisten</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="182"/>
+        <location filename="../scripts/mainscripts.js" line="183"/>
         <source>My Subscriptions</source>
         <translation>Mein Abonnement</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="195"/>
+        <location filename="../scripts/mainscripts.js" line="196"/>
         <source>Video Info</source>
         <translation>Video Info</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="204"/>
+        <location filename="../scripts/mainscripts.js" line="206"/>
         <source>Video Playback</source>
         <translation>Video abspielen</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="214"/>
         <source>Downloads</source>
-        <translation>Downloads</translation>
+        <translation type="obsolete">Downloads</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="222"/>
         <source>date</source>
-        <translation>datum</translation>
+        <translation type="obsolete">datum</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="225"/>
         <source>views</source>
-        <translation>aufrufe</translation>
+        <translation type="obsolete">aufrufe</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="228"/>
         <source>relevance</source>
-        <translation>relevanz</translation>
+        <translation type="obsolete">relevanz</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="231"/>
         <source>rating</source>
-        <translation>bewertung</translation>
+        <translation type="obsolete">bewertung</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="239"/>
+        <location filename="../scripts/mainscripts.js" line="218"/>
         <source>Search </source>
         <translation>Suchlauf</translation>
     </message>
@@ -1567,39 +1692,32 @@
 <context>
     <name>settings</name>
     <message>
-        <location filename="../scripts/settings.js" line="126"/>
-        <location filename="../scripts/settings.js" line="127"/>
         <source>High Quality</source>
-        <translation>Hohe Qualität</translation>
+        <translation type="obsolete">Hohe Qualität</translation>
     </message>
     <message>
-        <location filename="../scripts/settings.js" line="128"/>
         <source>Paused</source>
-        <translation>Pausiert</translation>
+        <translation type="obsolete">Pausiert</translation>
     </message>
     <message>
-        <location filename="../scripts/settings.js" line="131"/>
         <source>Automatic</source>
-        <translation>Automatisch</translation>
+        <translation type="obsolete">Automatisch</translation>
     </message>
     <message>
         <source>Media Player</source>
         <translation type="obsolete">Media Player</translation>
     </message>
     <message>
-        <location filename="../scripts/settings.js" line="133"/>
         <source>Date</source>
-        <translation>Datum</translation>
+        <translation type="obsolete">Datum</translation>
     </message>
     <message>
-        <location filename="../scripts/settings.js" line="134"/>
         <source>Dark</source>
-        <translation>Dunkel</translation>
+        <translation type="obsolete">Dunkel</translation>
     </message>
     <message>
-        <location filename="../scripts/settings.js" line="135"/>
         <source>English</source>
-        <translation>Englisch</translation>
+        <translation type="obsolete">Englisch</translation>
     </message>
 </context>
 <context>
