@@ -130,6 +130,7 @@ function loadArchiveView() {
     var loader = viewsModel.children[windowView.currentIndex + 1];
     windowView.currentItem.visible = false;
     loader.source = "ArchiveListView.qml";
+    loader.item.playVideos.connect(loadPlaybackView);
     notificationArea.addTitle(qsTr("Archive"));
     windowView.incrementCurrentIndex();
 }
@@ -187,7 +188,7 @@ function loadVideoInfo(video) {
     var loader = viewsModel.children[windowView.currentIndex + 1];
     windowView.currentItem.visible = false;
     loader.source = "VideoInfoView.qml";
-//    loader.item.playVideo.connect(loadPlaybackView);
+    loader.item.playVideo.connect(loadPlaybackView);
     loader.item.goToVideo.connect(loadVideoInfo);
     loader.item.authorClicked.connect(loadUserVideos);
     loader.item.search.connect(search);
@@ -197,6 +198,7 @@ function loadVideoInfo(video) {
 }
 
 function loadPlaybackView(videoList) {
+    Controller.setOrientation("Landscape");
     var loader = viewsModel.children[windowView.currentIndex + 1];
     windowView.currentItem.visible = false;
     toggleControls(false);
@@ -207,35 +209,12 @@ function loadPlaybackView(videoList) {
     loader.item.playbackStopped.connect(stopPlaying);
 }
 
-function loadDownloads() {
-    var loader = viewsModel.children[windowView.currentIndex + 1];
-    windowView.currentItem.visible = false;
-    loader.source = "DownloadListView.qml";
-    notificationArea.addTitle(qsTr("Downloads"));
-    windowView.incrementCurrentIndex();
-}
-
 function youtubeSearch(query, order) {
     /* Perform a YouTube search and open video list window */
 
-    var searchOrder = order;
-    if (order == qsTr("date")) {
-        searchOrder = "published";
-    }
-    else if (order == qsTr("views")) {
-        searchOrder = "viewCount";
-    }
-    else if (order == qsTr("relevance")) {
-        searchOrder = "relevance";
-    }
-    else if (order == qsTr("rating")) {
-        searchOrder = "rating";
-    }
-
     var safe = Settings.getSetting("safeSearch");
-
     var videoFeed = ("http://gdata.youtube.com/feeds/api/videos?v=2&max-results=50&safeSearch=" + safe + "&q="
-                     + encodeURIComponent(query).replace(" ", "+") + "&orderby=" + searchOrder);
+                     + encodeURIComponent(query).replace(" ", "+") + "&orderby=" + order);
     loadVideos(videoFeed, qsTr("Search ") + "('" + query + "')");
 }
 
@@ -279,6 +258,8 @@ function toggleControls(showOrHide) {
 }
 
 function stopPlaying() {
+    Controller.setOrientation(Settings.getSetting("screenOrientation"));
     toggleControls(true);
     goToPreviousView();
+
 }
