@@ -3,7 +3,7 @@
 function appendVideoFeed() {
     videoListModel.loading = true;
 
-    var startIndex = videoList.count + 1;
+    var startIndex = videoListModel.count + 1;
     var doc = new XMLHttpRequest();
     doc.onreadystatechange = function() {
         if (doc.readyState == XMLHttpRequest.DONE) {
