@@ -1,6 +1,7 @@
 #include "youtube.h"
 #include <QtNetwork/QNetworkRequest>
 #include <QtNetwork/QNetworkReply>
+#include <QtNetwork/QNetworkCookieJar>
 #include <QString>
 #include <QRegExp>
 #include <QUrl>
@@ -11,8 +12,8 @@
 
 YouTube::YouTube(QObject *parent) :
     QObject(parent), developerKey("AI39si6x9O1gQ1Z_BJqo9j2n_SdVsHu1pk2uqvoI3tVq8d6alyc1og785IPCkbVY3Q5MFuyt-IFYerMYun0MnLdQX5mo2BueSw"), playbackFormat(18) {
-    pbMap["High quality"] = 18;
-    pbMap["Mobile"] = 5;
+    pbMap["hq"] = 18;
+    pbMap["mobile"] = 5;
 }
 
 void YouTube::setNetworkAccessManager(QNetworkAccessManager *manager) {
@@ -349,7 +350,6 @@ void YouTube::getVideoUrl(const QString &playerUrl) {
     request.setUrl(QUrl(playerUrl));
     connect(manager, SIGNAL(finished(QNetworkReply*)), this, SLOT(parseVideoPage(QNetworkReply*)));
     manager->get(request);
-
 }
 
 void YouTube::parseVideoPage(QNetworkReply *reply) {
@@ -388,3 +388,41 @@ void YouTube::parseVideoPage(QNetworkReply *reply) {
     reply->deleteLater();
     manager->deleteLater();
 }
+
+void YouTube::parseVideoPage() {
+    QNetworkReply *reply = qobject_cast<QNetworkReply*>(sender());
+
+    QMap<int, QByteArray> formats;
+    QByteArray response = reply->readAll();
+    response = response.simplified().replace(QByteArray(" "), QByteArray(""));
+    int pos = response.indexOf("\",\"fmt_url_map\":\"") + 17;
+    int pos2 = response.indexOf('\"', pos);
+    response = response.mid(pos, pos2 - pos);
+    QList<QByteArray> parts = response.split('|');
+    int key = parts.first().toInt();
+    for (int i = 1; i < parts.length(); i++) {
+        QByteArray part = parts[i];
+        QList<QByteArray> keyAndValue = part.split(',');
+        QByteArray url = keyAndValue.first().replace(QByteArray("\\/"), QByteArray("/")).replace(QByteArray("\\u0026"), QByteArray("&"));
+        formats[key] = url;
+        key = keyAndValue.last().toInt();
+    }
+    QList<int> flist;
+    flist << 22 << 35 << 34 << 18 << 5;
+    QByteArray videoUrl = "";
+    int index = flist.indexOf(playbackFormat);
+    while ((videoUrl == "") && index < flist.size()) {
+        videoUrl = formats.value(flist.at(index), "");
+        index++;
+    }
+    if (videoUrl == "") {
+        emit alert(tr("Error: Unable to retrieve video"));
+        emit videoUrlError();
+    }
+    else {
+        emit gotVideoUrl(QString(videoUrl));
+        qDebug() << videoUrl;
+    }
+    reply->deleteLater();
+}
+
